%define anolis_release 2
Name:           jq
Version:        1.7.1
Release:        %{anolis_release}%{?dist}
Summary:        Command-line JSON processor

License:        MIT and ASL 2.0 and CC-BY and GPLv3
URL:            https://jqlang.github.io/jq/
Source0:        https://github.com/jqlang/jq/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz

# https://github.com/jqlang/jq/commit/a09a4dfd55e6c24d04b35062ccfe4509748b1dd3
Patch0:         Fix-CVE-2024-53427.patch

BuildRequires:  gcc
BuildRequires:  flex
BuildRequires:  bison
BuildRequires:  chrpath
BuildRequires:  oniguruma-devel
BuildRequires:  make
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  chrpath

%ifarch x86_64
BuildRequires:  valgrind
%endif


%description
lightweight and flexible command-line JSON processor

 jq is like sed for JSON data – you can use it to slice
 and filter and map and transform structured data with
 the same ease that sed, awk, grep and friends let you
 play with text.

 It is written in portable C, and it has zero runtime
 dependencies.

 jq can mangle the data format that you have into the
 one that you want with very little effort, and the
 program to do so is often shorter and simpler than
 you'd expect.

%package devel
Summary:	Development files for %{name}
Requires:	%{name} = %{version}-%{release}

%description devel
Development files for %{name}

%package doc
Summary: Documents for %{name}
BuildArch: noarch
Requires: %{name} = %{version}-%{release}

%description  doc
Doc pages for %{name}


%prep
%autosetup -p1 -n %{name}-%{version}

%build
autoreconf -fi
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -name '*.la' -exec rm -f {} ';'

# Delete build-time RPATH that is unnecessary on an installed
# system - rhbz#1987608
chrpath -d %{buildroot}%{_bindir}/%{name}

rm -fr %{buildroot}%{_datadir}/doc

%check
# Valgrind used, so restrict architectures for check
%ifarch x86_64
make check
%endif

%files
%license COPYING
%{_bindir}/%{name}
%{_libdir}/libjq.so.*
%{_mandir}/man1/jq.1*

%files doc
%doc AUTHORS NEWS.md README.md

%files devel
%{_includedir}/jq.h
%{_includedir}/jv.h
%{_libdir}/libjq.so
%{_libdir}/pkgconfig/libjq.pc

%changelog
* Fri Mar 28 2025 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.7.1-2
- to #IBX0H7
- add patch to fix CVE-2024-53427
- Project: TC2024080204
- Signed-off-by: mgb01105731 <mgb01105731@alibaba-inc.com>

* Fri Feb 21 2025 Xiaoping Liu <lxp01404969@alibaba-inc.com> - 1.7.1-1
- update to 1.7.1 from 1.6
- Remove patches because the changes already exist upstream

* Mon Aug 12 2024 lidongyue <dongyue@nfschina.com> - 1.6-16
- Fix CVE-2023-49355

* Tue Jan 24 2023 Funda Wang <fundawang@yeah.net> - 1.6-15
- Import package for anolis 23
